aris\_lite package
==================

.. note::

   Canonical CLI is ``aris`` with subcommands ``1go`` and ``calc``.
   Legacy flat CLI entries and legacy module-level ``main*``/``cli``
   aliases are deprecated and scheduled for removal in ``0.4.0``.

.. automodule:: aris_lite
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

aris\_lite.phenology module
---------------------------

.. automodule:: aris_lite.phenology
   :members:
   :show-inheritance:
   :undoc-members:

aris\_lite.water\_budget module
-------------------------------

.. automodule:: aris_lite.water_budget
   :members:
   :show-inheritance:
   :undoc-members:

aris\_lite.yield\_expectation module
------------------------------------

.. automodule:: aris_lite.yield_expectation
   :members:
   :show-inheritance:
   :undoc-members:
